==> babel-plugin-house-1.0.7.tgz: package/lib/mobxPatch.js <==
"use strict";

function _createForOfIteratorHelper(o, allowArrayLike) { var it; if (typeof Symbol === "undefined" || o[Symbol.iterator] == null) { if (Array.isArray(o) || (it = _unsupportedIterableToArray(o)) || allowArrayLike && o && typeof o.length === "number") { if (it) o = it; var i = 0; var F = function F() {}; return { s: F, n: function n() { if (i >= o.length) return { done: true }; return { done: false, value: o[i++] }; }, e: function e(_e) { throw _e; }, f: F }; } throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); } var normalCompletion = true, didErr = false, err; return { s: function s() { it = o[Symbol.iterator](); }, n: function n() { var step = it.next(); normalCompletion = step.done; return step; }, e: function e(_e2) { didErr = true; err = _e2; }, f: function f() { try { if (!normalCompletion && it.return != null) it.return(); } finally { if (didErr) throw err; } } }; }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }

const babel = require('babel-core');

const t = require('babel-types');

const utils = require('./utils');

function transExpressionStatement(path) {
  const node = path.node;

  if (t.isCallExpression(node.expression)) {
    if (t.isIdentifier(node.expression.callee) && node.expression.callee.name === 'endAction') {
      let args = node.expression.arguments;
      args = args.concat(t.identifier('actionName'));
      node.expression.arguments = args;
    }
  }
}

function transFunctionDeclaration() {
  const node = path.node;

  if (t.isIdentifier(path.node.id) && node.id.name === 'executeAction') {
    if (t.isBlockStatement(node.body)) {
      let express = utils.addLog(path.node.id.name);
      node.body.body.unshift(express);

      var _iterator = _createForOfIteratorHelper(node.body.body),
          _step;

      try {
        for (_iterator.s(); !(_step = _iterator.n()).done;) {
          let item = _step.value;

          if (t.isExpressionStatement(item) && t.isCallExpression(item.expression)) {
            if (t.isIdentifier(item.expression.callee) && item.expression.callee.name === 'endAction') {
              let args = item.expression.arguments;
              args = args.concat(t.identifier('actionName'));
              item.expression.arguments = args;
              break;
            }
          }
        }
      } catch (err) {
        _iterator.e(err);
      } finally {
        _iterator.f();
      }
    }
  }

  if (t.isIdentifier(path.node.id) && node.id.name === 'endAction') {
    node.params = node.params.concat(t.identifier('actionName'));

    if (t.isBlockStatement(node.body)) {
      let express = utils.addLog(path.node.id.name);
      node.body.body.unshift(express);

      var _iterator2 = _createForOfIteratorHelper(node.body.body),
          _step2;

      try {
        for (_iterator2.s(); !(_step2 = _iterator2.n()).done;) {
          let item = _step2.value;

          if (t.isIfStatement(item)) {
            if (t.isExpressionStatement(item.consequent) && t.isCallExpression(item.consequent.expression)) {
              let subExpress = item.consequent.expression;

              if (t.isIdentifier(subExpress.callee) && subExpress.callee.name === 'spyReportEnd') {
                let subArgs = subExpress.arguments[0];

                if (t.isObjectExpression(subArgs)) {
                  console.log(subArgs);
                  const attr = t.objectProperty(t.identifier('actionName'), t.identifier('actionName'));
                  subArgs.properties = subArgs.properties.concat(attr);
                }
              }
            }
          }
        }
      } catch (err) {
        _iterator2.e(err);
      } finally {
        _iterator2.f();
      }
    }
  }
}

module.exports = {
  transExpressionStatement,
  transFunctionDeclaration
};

==> babel-plugin-house-1.0.8.tgz: package/lib/mobxPatch.js <==
"use strict";

function _createForOfIteratorHelper(o, allowArrayLike) { var it; if (typeof Symbol === "undefined" || o[Symbol.iterator] == null) { if (Array.isArray(o) || (it = _unsupportedIterableToArray(o)) || allowArrayLike && o && typeof o.length === "number") { if (it) o = it; var i = 0; var F = function F() {}; return { s: F, n: function n() { if (i >= o.length) return { done: true }; return { done: false, value: o[i++] }; }, e: function e(_e) { throw _e; }, f: F }; } throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); } var normalCompletion = true, didErr = false, err; return { s: function s() { it = o[Symbol.iterator](); }, n: function n() { var step = it.next(); normalCompletion = step.done; return step; }, e: function e(_e2) { didErr = true; err = _e2; }, f: function f() { try { if (!normalCompletion && it.return != null) it.return(); } finally { if (didErr) throw err; } } }; }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }

const babel = require('babel-core');

const t = require('babel-types');

const utils = require('./utils');

function transExpressionStatement(path) {
  const node = path.node;

  if (t.isCallExpression(node.expression)) {
    if (t.isIdentifier(node.expression.callee) && node.expression.callee.name === 'endAction') {
      let args = node.expression.arguments;
      args = args.concat(t.identifier('actionName'));
      node.expression.arguments = args;
    }
  }
}

function transFunctionDeclaration(path) {
  const node = path.node;

  if (t.isIdentifier(path.node.id) && node.id.name === 'executeAction') {
    if (t.isBlockStatement(node.body)) {
      let express = utils.addLog(path.node.id.name);
      node.body.body.unshift(express);

      var _iterator = _createForOfIteratorHelper(node.body.body),
          _step;

      try {
        for (_iterator.s(); !(_step = _iterator.n()).done;) {
          let item = _step.value;

          if (t.isExpressionStatement(item) && t.isCallExpression(item.expression)) {
            if (t.isIdentifier(item.expression.callee) && item.expression.callee.name === 'endAction') {
              let args = item.expression.arguments;
              args = args.concat(t.identifier('actionName'));
              item.expression.arguments = args;
              break;
            }
          }
        }
      } catch (err) {
        _iterator.e(err);
      } finally {
        _iterator.f();
      }
    }
  }

  if (t.isIdentifier(path.node.id) && node.id.name === 'endAction') {
    node.params = node.params.concat(t.identifier('actionName'));

    if (t.isBlockStatement(node.body)) {
      let express = utils.addLog(path.node.id.name);
      node.body.body.unshift(express);

      var _iterator2 = _createForOfIteratorHelper(node.body.body),
          _step2;

      try {
        for (_iterator2.s(); !(_step2 = _iterator2.n()).done;) {
          let item = _step2.value;

          if (t.isIfStatement(item)) {
            if (t.isExpressionStatement(item.consequent) && t.isCallExpression(item.consequent.expression)) {
              let subExpress = item.consequent.expression;

              if (t.isIdentifier(subExpress.callee) && subExpress.callee.name === 'spyReportEnd') {
                let subArgs = subExpress.arguments[0];

                if (t.isObjectExpression(subArgs)) {
                  console.log(subArgs);
                  const attr = t.objectProperty(t.identifier('actionName'), t.identifier('actionName'));
                  subArgs.properties = subArgs.properties.concat(attr);
                }
              }
            }
          }
        }
      } catch (err) {
        _iterator2.e(err);
      } finally {
        _iterator2.f();
      }
    }
  }
}

module.exports = {
  transExpressionStatement,
  transFunctionDeclaration
};
